==> vdcpy-0.0.9.tar.gz: vdcpy-0.0.9/tests/project_tests/add_project_test.py <==
import unittest

import vdcpy.user as vdc_user
import vdcpy.project as vdc_project
import tests.utils.project_util as project_util
import tests.utils.user_util as user_util

class AddProject(unittest.TestCase):

    def setUp(self):
        user_util.delete_unittest_users()
        user_util.add_unittest_user()

    def test_successful_add_project(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']

        project_info = {
            'title': 'unittest_title',
            'created_by': user_id,
            'size': '1_gb',
            'visibility': 'open'
        }
        new_project = vdc_project.add_project(project_info)
        self.assertEqual(type(new_project), dict)

    def test_fail_add_project_no_title(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        
        project_info = {
            # 'title': 'unittest_title',
            'created_by': user_id,
            'size': '1_gb',
            'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(project_info)
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'title is required'}"
            )

    def test_fail_add_project_no_visibility(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        
        project_info = {
            'title': 'unittest_title',
            'created_by': user_id,
            'size': '1_gb',
            # 'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(project_info)
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'visibility is required'}"
            )

    def test_fail_add_project_no_size(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        
        project_info = {
            'title': 'unittest_title',
            'created_by': user_id,
            # 'size': '1_gb',
            'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(project_info)
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'size is required'}"
            )

    def test_fail_add_project_no_created_by(self):
        
        project_info = {
            'title': 'unittest_title',
            'size': '1_gb',
            'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(project_info)
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'created_by is required'}"
            )

    def TearDown(self):
        project_util.delete_unittest_project()
        user_util.delete_unittest_users()

==> vdcpy-0.0.11.tar.gz: vdcpy-0.0.11/tests/project_tests/add_project_test.py <==
import unittest

import vdcpy.user as vdc_user
import vdcpy.project as vdc_project
import tests.utils.project_util as project_util
import tests.utils.user_util as user_util

class AddProject(unittest.TestCase):

    def setUp(self):
        user_util.delete_unittest_users()
        user_util.add_unittest_user()

    def test_successful_add_project(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']

        project_info = {
            'title': 'unittest_title',
            'created_by': user_id,
            'size': '1_gb',
            'visibility': 'open'
        }
        new_project = vdc_project.add_project(project_info, auth_token='t3st')
        self.assertEqual(type(new_project), dict)

    def test_fail_add_project_no_title(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        
        project_info = {
            # 'title': 'unittest_title',
            'created_by': user_id,
            'size': '1_gb',
            'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(
                project_info, auth_token='t3st'
            )
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'title is required'}"
            )

    def test_fail_add_project_no_visibility(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        
        project_info = {
            'title': 'unittest_title',
            'created_by': user_id,
            'size': '1_gb',
            # 'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(
                project_info, auth_token='t3st'
            )
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'visibility is required'}"
            )

    def test_fail_add_project_no_size(self):
        # Get unittest user id
        user_list = vdc_user.get_users(email='test@test.test')
        user_id = user_list[0]['id']
        
        project_info = {
            'title': 'unittest_title',
            'created_by': user_id,
            # 'size': '1_gb',
            'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(
                project_info, auth_token='t3st'
            )
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'size is required'}"
            )

    def test_fail_add_project_no_created_by(self):
        
        project_info = {
            'title': 'unittest_title',
            'size': '1_gb',
            'visibility': 'open'
        }
        try:
            new_project = vdc_project.add_project(
                project_info, auth_token='t3st'
            )
            self.assertEqual(new_project, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding project: 400 - {'message': 'created_by is required'}"
            )

    def TearDown(self):
        project_util.delete_unittest_project()
        user_util.delete_unittest_users()
